@@ -2,11 +2,9 @@
 """
     __init__
 
-   
     Python API for prestashop
 
     :copyright: © 2013 by Openlabs Technologies & Consulting (P) Limited
     :license: BSD, see LICENSE for more details.
 """
-from .api import PrestaShopWebservice, PrestaShopWebserviceException
-
+from .api import PrestaShopWebservice, PrestaShopWebserviceException    # noqa
